@@ -1,11 +1,14 @@
 package SQL::Statement::Operation;
 
+use strict;
+use warnings;
+
 use vars qw(@ISA);
 require Carp;
 
 require SQL::Statement::Term;
 
-our $VERSION = '1.28';
+our $VERSION = '1.29';
 
 @ISA = qw(SQL::Statement::Term);
 
@@ -49,6 +52,18 @@ Return the result of the operation of the term by calling L<operate>
 I<Abstract> method which will do the operation of the term. Must be
 overridden by derived classes.
 
+=head2 op
+
+Returns the name of the executed operation.
+
+=head2 left
+
+Returns the left operand (if any).
+
+=head2 right
+
+Returns the right operand (if any).
+
 =head2 DESTROY
 
 Destroys the term and undefines the weak reference to the owner as well
@@ -68,10 +83,19 @@ sub new
     return $self;
 }
 
+sub op    { return $_[0]->{OP}; }
+sub left  { return $_[0]->{LEFT}; }
+sub right { return $_[0]->{RIGHT}; }
+
 sub operate($)
 {
     Carp::confess(
-          sprintf( q{pure virtual function 'operate' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+                   sprintf(
+                            q{pure virtual function 'operate' called on %s for %s},
+                            ref( $_[0] ) || __PACKAGE__,
+                            $_[0]->{OP}
+                          )
+                 );
 }
 
 sub DESTROY
@@ -382,7 +406,9 @@ sub operate($)
 
     foreach my $r (@right)
     {
-        last if $expr |= ( looks_like_number($left) && looks_like_number($r) ) ? $left == $r : $left eq $r;
+        last
+          if $expr |=
+              ( looks_like_number($left) && looks_like_number($r) ) ? $left == $r : $left eq $r;
     }
 
     return $expr;
@@ -438,7 +464,9 @@ sub operate($)
     my @right = map { $_->value($eval); } @{ $self->{RIGHT} };
     my $expr  = 0;
 
-    if ( looks_like_number($left) && looks_like_number( $right[0] ) && looks_like_number( $right[1] ) )
+    if (    looks_like_number($left)
+         && looks_like_number( $right[0] )
+         && looks_like_number( $right[1] ) )
     {
         $expr = ( $left >= $right[0] ) && ( $left <= $right[1] );
     }
@@ -516,13 +544,23 @@ sub operate($)
 sub numcmp($)
 {
     Carp::confess(
-           sprintf( q{pure virtual function 'numcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+                   sprintf(
+                            q{pure virtual function 'numcmp' called on %s for %s},
+                            ref( $_[0] ) || __PACKAGE__,
+                            $_[0]->{OP}
+                          )
+                 );
 }
 
 sub strcmp($)
 {
     Carp::confess(
-           sprintf( q{pure virtual function 'strcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+                   sprintf(
+                            q{pure virtual function 'strcmp' called on %s for %s},
+                            ref( $_[0] ) || __PACKAGE__,
+                            $_[0]->{OP}
+                          )
+                 );
 }
 
 package SQL::Statement::Operation::Equal;
@@ -867,7 +905,12 @@ sub right($)
 sub regexp($)
 {
     Carp::confess(
-           sprintf( q{pure virtual function 'regexp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+                   sprintf(
+                            q{pure virtual function 'regexp' called on %s for %s},
+                            ref( $_[0] ) || __PACKAGE__,
+                            $_[0]->{OP}
+                          )
+                 );
 }
 
 sub operate($)
