@@ -2,13 +2,19 @@
 package SQL::Statement::RAM;
 ############################
 
+use strict;
+use warnings;
+
 use vars qw($VERSION);
-$VERSION = '1.28';
+$VERSION = '1.29';
 
 ####################################
 package SQL::Statement::RAM::Table;
 ####################################
 
+use strict;
+use warnings;
+
 require SQL::Eval;
 
 use vars qw(@ISA);
@@ -59,7 +65,7 @@ sub fetch_row
 sub insert_new_row
 {
     my ( $self, $data, $fields ) = @_;
-    push @{$self->{records}}, clone($fields);
+    push @{ $self->{records} }, clone($fields);
     return 1;
 }
 ##################################
