@@ -1,7 +1,10 @@
 package SQL::Statement::Util;
 
+use strict;
+use warnings;
+
 use vars qw($VERSION);
-$VERSION = '1.28';
+$VERSION = '1.29';
 
 sub type
 {
@@ -23,7 +26,8 @@ sub new
     $display_name ||= $col_name;
 
     # print " $col_name !\n";
-    if ( $col_name && ( ( $col_name =~ m/^(".+")\.(.*)$/ ) || ( $col_name =~ m/^([^.]*)\.(.*)$/ ) ) )
+    if ( $col_name
+         && ( ( $col_name =~ m/^(".+")\.(.*)$/ ) || ( $col_name =~ m/^([^.]*)\.(.*)$/ ) ) )
     {
         $table_name = $1;
         $col_name   = $2;
